@@ -40,6 +40,7 @@
 #include "libxfce4windowing-private.h"
 #include "xfw-gdk-private.h"
 #include "xfw-monitor-private.h"
+#include "libxfce4windowing-visibility.h"
 
 #define XFW_MONITOR_GET_PRIVATE(monitor) ((XfwMonitorPrivate *)xfw_monitor_get_instance_private(XFW_MONITOR(monitor)))
 
@@ -1003,7 +1004,7 @@ _xfw_monitor_set_physical_size(XfwMonitor *monitor, guint width_mm, guint height
         priv->width_mm = width_mm;
         priv->pending_changes |= MONITOR_PENDING_PHYSICAL_WIDTH;
     }
-    if (priv->width_mm != width_mm) {
+    if (priv->height_mm != height_mm) {
         priv->height_mm = height_mm;
         priv->pending_changes |= MONITOR_PENDING_PHYSICAL_HEIGHT;
     }
@@ -1064,7 +1065,7 @@ _xfw_monitor_guess_primary_monitor(GList *monitors) {
             return monitor;
         }
 
-        GdkRectangle geom;
+        GdkRectangle geom = { 0 };
         xfw_monitor_get_logical_geometry(monitor, &geom);
         if (geom.x == 0 && geom.y == 0) {
             // The topmost, leftmost monitor could be considered primary.
@@ -1082,6 +1083,48 @@ _xfw_monitor_guess_primary_monitor(GList *monitors) {
     return maybe_primary;
 }
 
+/* The idea here is to base the identifier off make+model+serial: this should
+ * ensure the ID is specific to a particular piece of monitor hardware, and it
+ * should be stable between X11 and Wayland.  If we don't have a serial number,
+ * then we'll include the connector.  That will at least identify it as a
+ * particular specific monitor model plugged into a particular port on the
+ * machine, which for many people will end up being the same all the time.  If
+ * we're lacking the make and model and serial number, we're in trouble, and
+ * the best we can do is the connector.
+ *
+ * If we had access to the EDID everywhere, I'd prefer to just hash the raw
+ * value and have that be it.  But we don't get EDID on Wayland, so we can't
+ * use it.
+ */
+gchar *
+_xfw_monitor_build_identifier(const gchar *make, const gchar *model, const gchar *serial, const gchar *connector) {
+    GChecksum *cksum = g_checksum_new(G_CHECKSUM_SHA1);
+
+    const guchar *sep = (const guchar *)"|";
+
+    if (make != NULL) {
+        g_checksum_update(cksum, (const guchar *)make, -1);
+        g_checksum_update(cksum, sep, -1);
+    }
+    if (model != NULL) {
+        g_checksum_update(cksum, (const guchar *)model, -1);
+        g_checksum_update(cksum, sep, -1);
+    }
+    if (serial != NULL) {
+        g_checksum_update(cksum, (const guchar *)serial, -1);
+    }
+
+    if ((make == NULL && model == NULL) || serial == NULL) {
+        if (make == NULL && model == NULL) {
+            g_checksum_update(cksum, sep, -1);
+        }
+        g_checksum_update(cksum, (const guchar *)connector, -1);
+    }
+
+    gchar *identifier = g_strdup(g_checksum_get_string(cksum));
+    g_checksum_free(cksum);
+    return identifier;
+}
 
 MonitorPendingChanges
 _xfw_monitor_notify_pending_changes(XfwMonitor *monitor) {
@@ -1124,3 +1167,6 @@ _xfw_monitor_notify_pending_changes(XfwMonitor *monitor) {
 
     return old_pending_changes;
 }
+
+#define __XFW_MONITOR_C__
+#include <libxfce4windowing-visibility.c>
